==> nexstate-1.1.0.tar.gz: test/nexstate_test.dart <==
import 'package:nexstate/nexstate.dart';
import 'package:test/test.dart';

void main() {
  test('Manages State Correctly', () async {
    final userStore = UserStore();

    const johnDoe = User(
      firstName: 'John',
      lastName: 'Doe',
      userName: 'john_doe',
    );

    const janeDoe = User(
      firstName: 'Jane',
      lastName: 'Doe',
      userName: 'jane_doe',
    );

    await userStore.dispatch(const LogIn(johnDoe));
    expect(userStore.state, johnDoe);

    await userStore.dispatchCompound(const SwitchAndLogout(janeDoe));
    expect(userStore.state, null);
  });
}

class User {
  final String firstName;
  final String lastName;
  final String userName;

  const User({
    required this.firstName,
    required this.lastName,
    required this.userName,
  });

  @override
  String toString() {
    return {
      'firstName': firstName,
      'lastName': lastName,
      'userName': userName,
    }.toString();
  }
}

class UserStore extends Store<User?> {
  UserStore() : super(null, logger: true);
}

class LogIn extends Action<User?> {
  final User user;

  const LogIn(this.user) : super();

  @override
  Future<User> activate(User? state) async => user;
}

class LogOut extends Action<User?> {
  const LogOut() : super();

  @override
  // ignore: prefer_void_to_null
  Future<Null> activate(User? state) async => null;
}

class SwitchAndLogout extends CompoundAction<User?> {
  final User user;

  const SwitchAndLogout(this.user) : super();

  @override
  Future<void> activate(User? state, Dispatcher<User?> dispatch) async {
    await dispatch(LogIn(user));

    await Future.delayed(
      const Duration(seconds: 2),
      () => dispatch(const LogOut()),
    );
  }
}

==> nexstate-1.1.1.tar.gz: test/nexstate_test.dart <==
import 'package:nexstate/nexstate.dart';
import 'package:test/test.dart';

void main() {
  test('Manages State Correctly', () async {
    final userStore = UserStore();

    const johnDoe = User(
      firstName: 'John',
      lastName: 'Doe',
      userName: 'john_doe',
    );

    const janeDoe = User(
      firstName: 'Jane',
      lastName: 'Doe',
      userName: 'jane_doe',
    );

    await userStore.dispatch(const LogIn(johnDoe));
    expect(userStore.state, johnDoe);

    await userStore.dispatchCompound(const SwitchAndLogout(janeDoe));
    expect(userStore.state, null);
  });
}

class User {
  final String firstName;
  final String lastName;
  final String userName;

  const User({
    required this.firstName,
    required this.lastName,
    required this.userName,
  });

  @override
  String toString() {
    return {
      'firstName': firstName,
      'lastName': lastName,
      'userName': userName,
    }.toString();
  }
}

class UserStore extends Store<User?> {
  UserStore() : super(null, logger: true);
}

class LogIn extends Action<User?> {
  final User user;

  const LogIn(this.user) : super();

  @override
  Future<User?> activate(User? state) async => user;
}

class LogOut extends Action<User?> {
  const LogOut() : super();

  @override
  Future<User?> activate(User? state) async => null;
}

class SwitchAndLogout extends CompoundAction<User?> {
  final User user;

  const SwitchAndLogout(this.user) : super();

  @override
  Future<void> activate(User? state, Dispatcher<User?> dispatch) async {
    await dispatch(LogIn(user));

    await Future.delayed(
      const Duration(seconds: 2),
      () => dispatch(const LogOut()),
    );
  }
}
